==> bacula-docs-1.38.0.tar.gz: bacula-docs-1.38.0/home-page/pages/maillists.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
        <td class="contentTopic">
                Email Lists
        </td>
</tr>
<tr>
        <td class="content">

<b>Bacula</b> has four email lists which are described below with
links to subscribe, unsubscribe, or modify your account.
For general information on these lists, please see
<a href="http://sourceforge.net/mail/?group_id=50727">Bacula Mailing Lists at SourceForge</a>.
<p>For email archives see below.</p>

<h3>bacula-announce</h3>
The <b>bacula-announce</b> list is a read only low volume list for those
users who wish to be notified when there are important events
(important bugs, new releases, ...). We recommend that all
users subscribe to this list. Do so by following the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-announce">
Bacula Announce List Subscription/Unsubscription/Modification</a>.
Please do not send email directly to this list.

<p>It is also possible to get email notification whenever a new package
is released on SourceForge. This is accomplished by going to
the <a href="http://sourceforge.net/projects/bacula">Bacula SourceForge
Project</a> page and clicking on the little letter or mail icon
<img src="images/mail16d.png" alt="" width="15" height="15"> under the heading <b>Monitor</b> in the
row corresponding to the package you want to monitor.
</p>

<h3>bacula-users</h3>
The <b>bacula-users</b> list is the general forum to
ask questions about Bacula or respond to questions
from other users. The volume on this list is generally
moderate, but can vary. All users are encouraged to subscribe
and to participate.
Due to the increasing volume of spam, you must be subscribed
before you can send email to this list.
To subscribe follow the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-users">Bacula Users List Subscription/Unsubscription/Modification</a>.
<p>
To send an email to the Bacula Users List, use the following
address: <b>bacula-users at lists.sourceforge.net</b>.
The previous address was modified to prevent easy use by spammers. To use it,
you must replace the <b>at</b> with an @ symbol.
</p>

<h3>bacula-devel</h3>
The <b>bacula-devel</b> list is for those users who wish to
communicate directly with the developers. The email volume
is currently quite low, but can vary.
To subscribe, please follow this link:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-devel">
Bacula Developers List Subscription/Unsubscription/Modification</a>.
<p>
To send an email to the Bacula Developers List, use the following
address: <b>bacula-devel at lists.sourceforge.net</b>.
The previous
address was modified to prevent easy use by spammers. To use it,
you must replace the <b>at</b> with an @ symbol.
</p>

<h3>bacula-bugs</h3>
The <b>bacula-bugs</b> list is a read only
list for those users who wish to be notified about new bugs
registered at: <a href="http://bugs.bacula.org">
http://bugs.bacula.org</a>. Please do not send email directly
to this list bug file a bug report in the bugs database mentioned
above.

To subscribe, follow follow the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-bugs">
http://lists.sourceforge.net/lists/listinfo/bacula-bugs</a>.

<h3>bacula-commits</h3>
The <b>bacula-commits</b> list is a read only
list for those users who wish to be receive a diff of each
commit to the CVS. Please do not email directly to this list.

You may subscribe by following the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-commits">
http://lists.sourceforge.net/lists/listinfo/bacula-commits</a>.


<h3>Archives</h3>
Most of the above email lists are archived on Source Forge, but they are
also archived on Gmane, which has better seach facilities. The
Gmane archives are at: <a href="http://news.gmane.org/search.php?match=bacula">
http://news.gmane.org/search.php?match=bacula</a>.


        </td>
</tr>
</table>
<? require_once("inc/footer.php"); ?>

==> bacula-docs-1.38.5.tar.gz: bacula-docs-1.38.5/home-page/pages/maillists.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
        <td class="contentTopic">
                Email Lists
        </td>
</tr>
<tr>
        <td class="content">

<b>Bacula</b> has four email lists which are described below with
links to subscribe, unsubscribe, or modify your account.
For general information on these lists, please see
<a href="http://sourceforge.net/mail/?group_id=50727">Bacula Mailing Lists at SourceForge</a>.
<p>For email archives see below.</p>

<h3>bacula-announce</h3>
The <b>bacula-announce</b> list is a read only low volume list for those
users who wish to be notified when there are important events
(important bugs, new releases, ...). We recommend that all
users subscribe to this list. Do so by following the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-announce">
Bacula Announce List Subscription/Unsubscription/Modification</a>.
Please do not send email directly to this list.

<p>It is also possible to get email notification whenever a new package
is released on SourceForge. This is accomplished by going to
the <a href="http://sourceforge.net/projects/bacula">Bacula SourceForge
Project</a> page and clicking on the little letter or mail icon
<img src="images/mail16d.png" alt="" width="15" height="15"> under the heading <b>Monitor</b> in the
row corresponding to the package you want to monitor.
</p>

<h3>bacula-users</h3>
The <b>bacula-users</b> list is the general forum to
ask questions about Bacula or respond to questions
from other users. The volume on this list is generally
moderate, but can vary. All users are encouraged to subscribe
and to participate.
Due to the increasing volume of spam, you must be subscribed
before you can send email to this list.
To subscribe follow the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-users">Bacula Users List Subscription/Unsubscription/Modification</a>.
<p>
To send an email to the Bacula Users List, use the following
address: <b>bacula-users at lists.sourceforge.net</b>.
The previous address was modified to prevent easy use by spammers. To use it,
you must replace the <b>at</b> with an @ symbol.
</p>

<h3>bacula-devel</h3>
The <b>bacula-devel</b> list is for those users who wish to
communicate directly with the developers. The email volume
is currently quite low, but can vary.
To subscribe, please follow this link:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-devel">
Bacula Developers List Subscription/Unsubscription/Modification</a>.
<p>
To send an email to the Bacula Developers List, use the following
address: <b>bacula-devel at lists.sourceforge.net</b>.
The previous
address was modified to prevent easy use by spammers. To use it,
you must replace the <b>at</b> with an @ symbol.
</p>

<h3>bacula-bugs</h3>
The <b>bacula-bugs</b> list is a read only
list for those users who wish to be notified about new bugs
registered at: <a href="http://bugs.bacula.org">
http://bugs.bacula.org</a>. Please do not send email directly
to this list bug file a bug report in the bugs database mentioned
above.

To subscribe, follow follow the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-bugs">
http://lists.sourceforge.net/lists/listinfo/bacula-bugs</a>.

<h3>bacula-commits</h3>
The <b>bacula-commits</b> list is a read only
list for those users who wish to be receive a diff of each
commit to the CVS. Please do not email directly to this list.

You may subscribe by following the instructions at:
<a href="http://lists.sourceforge.net/lists/listinfo/bacula-commits">
http://lists.sourceforge.net/lists/listinfo/bacula-commits</a>.


<h3>Archives</h3>
Most of the above email lists are archived on Source Forge, but they are
also archived on Gmane, which has better search facilities. The
Gmane archives are at: <a href="http://news.gmane.org/search.php?match=bacula">
http://news.gmane.org/search.php?match=bacula</a>.


        </td>
</tr>
</table>
<? require_once("inc/footer.php"); ?>
